@@ -106,6 +106,10 @@ QVariant NetworkModel::data(const QModelIndex &index, int role) const
                 return item->vpnState();
             case VpnType:
                 return item->vpnType();
+            case RxBytesRole:
+                return item->rxBytes();
+            case TxBytesRole:
+                return item->txBytes();
             default:
                 break;
         }
@@ -149,6 +153,8 @@ QHash<int, QByteArray> NetworkModel::roleNames() const
     roles[UuidRole] = "Uuid";
     roles[VpnState] = "VpnState";
     roles[VpnType] = "VpnType";
+    roles[RxBytesRole] = "RxBytes";
+    roles[TxBytesRole] = "TxBytes";
 
     return roles;
 }
@@ -210,6 +216,20 @@ void NetworkModel::initializeSignals(const NetworkManager::Device::Ptr &device)
     connect(device.data(), &NetworkManager::Device::ipInterfaceChanged, this, &NetworkModel::ipInterfaceChanged);
     connect(device.data(), &NetworkManager::Device::stateChanged, this, &NetworkModel::deviceStateChanged, Qt::UniqueConnection);
 
+    auto deviceStatistics = device->deviceStatistics();
+    connect(deviceStatistics.data(), &NetworkManager::DeviceStatistics::rxBytesChanged, this, [this, device](qulonglong rxBytes) {
+        for (auto *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+            item->setRxBytes(rxBytes);
+            updateItem(item);
+        }
+    });
+    connect(deviceStatistics.data(), &NetworkManager::DeviceStatistics::txBytesChanged, this, [this, device](qulonglong txBytes) {
+        for (auto *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
+            item->setTxBytes(txBytes);
+            updateItem(item);
+        }
+    });
+
     if (device->type() == NetworkManager::Device::Wifi) {
         NetworkManager::WirelessDevice::Ptr wifiDev = device.objectCast<NetworkManager::WirelessDevice>();
         connect(wifiDev.data(), &NetworkManager::WirelessDevice::networkAppeared, this, &NetworkModel::wirelessNetworkAppeared, Qt::UniqueConnection);
@@ -278,7 +298,7 @@ void NetworkModel::addActiveConnection(const NetworkManager::ActiveConnection::P
                 }
                 item->setVpnState(state);
             }
-            item->updateDetails();
+            item->invalidateDetails();
             qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection state changed to " << item->connectionState();
         }
     }
@@ -387,7 +407,7 @@ void NetworkModel::addConnection(const NetworkManager::Connection::Ptr &connecti
             item->setSsid(QString::fromUtf8(wirelessSetting->ssid()));
         }
 
-        item->updateDetails();
+        item->invalidateDetails();
 
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
@@ -470,7 +490,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
     item->setSsid(network->ssid());
     item->setType(NetworkManager::ConnectionSettings::Wireless);
     item->setSecurityType(securityType);
-    item->updateDetails();
+    item->invalidateDetails();
 
     const int index = m_list.count();
     beginInsertRows(QModelIndex(), index, index);
@@ -482,7 +502,7 @@ void NetworkModel::addWirelessNetwork(const NetworkManager::WirelessNetwork::Ptr
 void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QString &deviceUni)
 {
     bool createDuplicate = false;
-    NetworkModelItem *originalItem = 0;
+    NetworkModelItem *originalItem = nullptr;
 
     for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Connection, connection)) {
         if (!item->duplicate()) {
@@ -496,7 +516,7 @@ void NetworkModel::checkAndCreateDuplicate(const QString &connection, const QStr
 
     if (createDuplicate) {
         NetworkModelItem *duplicatedItem = new NetworkModelItem(originalItem);
-        duplicatedItem->updateDetails();
+        duplicatedItem->invalidateDetails();
 
         const int index = m_list.count();
         beginInsertRows(QModelIndex(), index, index);
@@ -513,12 +533,21 @@ void NetworkModel::onItemUpdated()
     }
 }
 
+void NetworkModel::setDeviceStatisticsRefreshRateMs(const QString &devicePath, uint refreshRate)
+{
+    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(devicePath);
+
+    if (device) {
+        device->deviceStatistics()->setRefreshRateMs(refreshRate);
+    }
+}
+
 void NetworkModel::updateItem(NetworkModelItem*item)
 {
     const int row = m_list.indexOf(item);
 
     if (row >= 0) {
-        item->updateDetails();
+        item->invalidateDetails();
         QModelIndex index = createIndex(row, 0);
         Q_EMIT dataChanged(index, index);
     }
@@ -565,7 +594,7 @@ void NetworkModel::activeConnectionStateChanged(NetworkManager::ActiveConnection
         beginResetModel();
         for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::ActiveConnection, activePtr->path())) {
             item->setConnectionState(state);
-            item->updateDetails();
+            item->invalidateDetails();
             qCDebug(PLASMA_NM) << "Item " << item->name() << ": active connection changed to " << item->connectionState();
         }
         endResetModel();
@@ -776,7 +805,7 @@ void NetworkModel::deviceStateChanged(NetworkManager::Device::State state, Netwo
         beginResetModel();
         for (NetworkModelItem *item : m_list.returnItems(NetworkItemsList::Device, device->uni())) {
             item->setDeviceState(state);
-            item->updateDetails();
+            item->invalidateDetails();
 //             qCDebug(PLASMA_NM) << "Item " << item->name() << ": device state changed to " << item->deviceState();
         }
         endResetModel();
